Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRobert Holcomb <bob_holcomb@hotmail.com>2007-04-13 08:22:32 +0400
committerRobert Holcomb <bob_holcomb@hotmail.com>2007-04-13 08:22:32 +0400
commit26735a66708885b1f461cde9f1c03307c9d91115 (patch)
treebeaea5ccb912bd431af15cf9a596b8fcd609910f /source/blender/nodes/intern/CMP_nodes/CMP_brightness.c
parentf7738575c94eaf215a95a1169ff3ea16d96862e6 (diff)
Added gamma, fixed typos in brightness
Diffstat (limited to 'source/blender/nodes/intern/CMP_nodes/CMP_brightness.c')
-rw-r--r--source/blender/nodes/intern/CMP_nodes/CMP_brightness.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/nodes/intern/CMP_nodes/CMP_brightness.c b/source/blender/nodes/intern/CMP_nodes/CMP_brightness.c
index bb411a47d34..c87307434b5 100644
--- a/source/blender/nodes/intern/CMP_nodes/CMP_brightness.c
+++ b/source/blender/nodes/intern/CMP_nodes/CMP_brightness.c
@@ -33,13 +33,13 @@
/* **************** Brigh and contrsast ******************** */
-static bNodeSocketType cmp_node_brightcontrsast_in[]= {
+static bNodeSocketType cmp_node_brightcontrast_in[]= {
{ SOCK_RGBA, 1, "Image", 0.8f, 0.8f, 0.8f, 1.0f, 0.0f, 1.0f},
{ SOCK_VALUE, 1, "bright", 0.0f, 0.0f, 0.0f, 0.0f, -100.0f, 100.0f},
{ SOCK_VALUE, 1, "contrast", 0.0f, 0.0f, 0.0f, 0.0f, -100.0f, 100.0f},
{ -1, 0, "" }
};
-static bNodeSocketType cmp_node_brightcontrsast_out[]= {
+static bNodeSocketType cmp_node_brightcontrast_out[]= {
{ SOCK_RGBA, 0, "Image", 0.0f, 0.0f, 0.0f, 1.0f, 0.0f, 1.0f},
{ -1, 0, "" }
};
@@ -77,7 +77,7 @@ static void do_brightnesscontrast(bNode *node, float *out, float *in)
}
}
-static void node_composit_exec_brightcontrsast(void *data, bNode *node, bNodeStack **in, bNodeStack **out)
+static void node_composit_exec_brightcontrast(void *data, bNode *node, bNodeStack **in, bNodeStack **out)
{
if(out[0]->hasoutput==0)
return;
@@ -94,16 +94,16 @@ static void node_composit_exec_brightcontrsast(void *data, bNode *node, bNodeSta
}
}
-bNodeType cmp_node_brighcontrast= {
+bNodeType cmp_node_brightcontrast= {
/* *next,*prev */ NULL, NULL,
/* type code */ CMP_NODE_BRIGHTCONTRAST,
/* name */ "Bright/Contrast",
/* width+range */ 140, 100, 320,
/* class+opts */ NODE_CLASS_OP_COLOR, NODE_OPTIONS,
/* input sock */ cmp_node_brightcontrsast_in,
/* output sock */ cmp_node_brightcontrsast_out,
/* storage */ "",
- /* execfunc */ node_composit_exec_brightcontrsast,
+ /* execfunc */ node_composit_exec_brightcontrast,
/* butfunc */ NULL,
/* initfunc */ NULL,
/* freestoragefunc */ NULL,
@@ -94,16 +94,16 @@ static void node_composit_exec_brightcontrsast(void *data, bNode *node, bNodeSta
/* width+range */ 140, 100, 320,
/* class+opts */ NODE_CLASS_OP_COLOR, NODE_OPTIONS,
- /* input sock */ cmp_node_brightcontrsast_in,
- /* output sock */ cmp_node_brightcontrsast_out,
+ /* input sock */ cmp_node_brightcontrast_in,
+ /* output sock */ cmp_node_brightcontrast_out,
/* storage */ "",